summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcombobox_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcombobox_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcombobox_imp.cpp114
1 files changed, 57 insertions, 57 deletions
diff --git a/kjsembed/qtbindings/qcombobox_imp.cpp b/kjsembed/qtbindings/qcombobox_imp.cpp
index 28cf620c..6ee231b8 100644
--- a/kjsembed/qtbindings/qcombobox_imp.cpp
+++ b/kjsembed/qtbindings/qcombobox_imp.cpp
@@ -21,12 +21,12 @@
*/
namespace KJSEmbed {
-TTQComboBoxImp::TQComboBoxImp( KJS::ExecState *exec, int mid, bool constructor )
+TQComboBoxImp::TQComboBoxImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQComboBoxImp::~TQComboBoxImp()
+TQComboBoxImp::~TQComboBoxImp()
{
}
@@ -41,7 +41,7 @@ void TQComboBoxImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -64,12 +64,12 @@ void TQComboBoxImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
EnumValue enums[] = {
// enum Policy
- { "NoInsertion", TTQComboBox::NoInsertion },
- { "AtTop", TTQComboBox::AtTop },
- { "AtCurrent", TTQComboBox::AtCurrent },
- { "AtBottom", TTQComboBox::AtBottom },
- { "AfterCurrent", TTQComboBox::AfterCurrent },
- { "BeforeCurrent", TTQComboBox::BeforeCurrent },
+ { "NoInsertion", TQComboBox::NoInsertion },
+ { "AtTop", TQComboBox::AtTop },
+ { "AtCurrent", TQComboBox::AtCurrent },
+ { "AtBottom", TQComboBox::AtBottom },
+ { "AfterCurrent", TQComboBox::AfterCurrent },
+ { "BeforeCurrent", TQComboBox::BeforeCurrent },
{ 0, 0 }
};
@@ -137,7 +137,7 @@ void TQComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -150,25 +150,25 @@ void TQComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQComboBox pointer from an Object.
*/
-TTQComboBox *TQComboBoxImp::toTQComboBox( KJS::Object &self )
+TQComboBox *TQComboBoxImp::toTQComboBox( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQComboBox *>( obj );
+ return dynamic_cast<TQComboBox *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQComboBox" )
+ if ( op->typeName() != "TQComboBox" )
return 0;
- return op->toNative<TTQComboBox>();
+ return op->toNative<TQComboBox>();
}
/**
@@ -190,7 +190,7 @@ KJS::Object TQComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &arg
break;
}
- TTQString msg = i18n("TQComboBoxCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQComboBoxCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -198,15 +198,15 @@ KJS::Object TQComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &arg
KJS::Object TQComboBoxImp::TQComboBox_1( KJS::ExecState *exec, const KJS::List &args )
{
#if 0
// Unsupported parameter TTQWidget *
return KJS::Value();
- TTQWidget * arg0; // Dummy
+ TQWidget * arg0; // Dummy
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
// We should now create an object of type TQComboBoxTQComboBox *ret = new TTQComboBox(
arg0,
arg1 );
@@ -219,15 +219,15 @@ KJS::Object TQComboBoxImp::TQComboBox_2( KJS::ExecState *exec, const KJS::List &
#if 0
bool arg0 = extractBool(exec, args, 0);
// Unsupported parameter TTQWidget *
return KJS::Value();
- TTQWidget * arg1; // Dummy
+ TQWidget * arg1; // Dummy
const char *arg2 = (args.size() >= 3) ? args[2].toString(exec).ascii() : 0;
// We should now create an object of type TQComboBoxTQComboBox *ret = new TTQComboBox(
arg0,
arg1,
@@ -427,7 +427,7 @@ KJS::Value TQComboBoxImp::call( KJS::ExecState *exec, KJS::Object &self, const K
break;
}
- TTQString msg = i18n( "TQComboBoxImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQComboBoxImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -444,7 +444,7 @@ KJS::Value TQComboBoxImp::count_4( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQComboBoxImp::insertStringList_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQStringList arg0 = extractTQStringList(exec, args, 0);
+ TQStringList arg0 = extractTQStringList(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -458,7 +458,7 @@ KJS::Value TQComboBoxImp::insertStringList_5( KJS::ExecState *exec, KJS::Object
KJS::Value TQComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQStrList arg0 = extractTQStrList(exec, args, 0);
+ TQStrList arg0 = extractTQStrList(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -472,10 +472,10 @@ KJS::Value TQComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQComboBoxImp::insertStrList_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TTQStrList *
return KJS::Value();
- const TTQStrList * arg0; // Dummy
+ const TQStrList * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -509,7 +509,7 @@ KJS::Value TQComboBoxImp::insertStrList_8( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQComboBoxImp::insertItem_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -523,7 +523,7 @@ KJS::Value TQComboBoxImp::insertItem_9( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::insertItem_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -537,9 +537,9 @@ KJS::Value TQComboBoxImp::insertItem_10( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::insertItem_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
+ TQString arg1 = extractTQString(exec, args, 1);
int arg2 = extractInt(exec, args, 2);
@@ -585,7 +585,7 @@ KJS::Value TQComboBoxImp::setCurrentItem_14( KJS::ExecState *exec, KJS::Object &
KJS::Value TQComboBoxImp::currentText_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->currentText( );
return KJS::String( ret );
@@ -594,7 +594,7 @@ KJS::Value TQComboBoxImp::currentText_15( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQComboBoxImp::setCurrentText_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
instance->setCurrentText(
arg0 );
@@ -607,7 +607,7 @@ KJS::Value TQComboBoxImp::text_17( KJS::ExecState *exec, KJS::Object &obj, const
int arg0 = extractInt(exec, args, 0);
- TTQString ret;
+ TQString ret;
ret = instance->text(
arg0 );
return KJS::String( ret );
@@ -621,14 +621,14 @@ KJS::Value TQComboBoxImp::pixmap_18( KJS::ExecState *exec, KJS::Object &obj, con
instance->pixmap(
arg0 );
- return KJS::Value(); // Returns 'const TTQPixmap *'
+ return KJS::Value(); // Returns 'const TQPixmap *'
}
KJS::Value TQComboBoxImp::changeItem_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -642,7 +642,7 @@ KJS::Value TQComboBoxImp::changeItem_19( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::changeItem_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -656,9 +656,9 @@ KJS::Value TQComboBoxImp::changeItem_20( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::changeItem_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
- TTQString arg1 = extractTQString(exec, args, 1);
+ TQString arg1 = extractTQString(exec, args, 1);
int arg2 = extractInt(exec, args, 2);
@@ -692,7 +692,7 @@ KJS::Value TQComboBoxImp::setAutoResize_23( KJS::ExecState *exec, KJS::Object &o
KJS::Value TQComboBoxImp::sizeHint_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQSize ret;
+ TQSize ret;
ret = instance->sizeHint( );
return convertToValue( exec, ret );
@@ -702,7 +702,7 @@ KJS::Value TQComboBoxImp::sizeHint_24( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQComboBoxImp::setPalette_25( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPalette arg0 = extractTQPalette(exec, args, 0);
+ TQPalette arg0 = extractTQPalette(exec, args, 0);
instance->setPalette(
arg0 );
@@ -713,7 +713,7 @@ KJS::Value TQComboBoxImp::setPalette_25( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::setFont_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFont arg0 = extractTQFont(exec, args, 0);
+ TQFont arg0 = extractTQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -775,7 +775,7 @@ KJS::Value TQComboBoxImp::maxCount_31( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQComboBoxImp::setInsertionPolicy_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQComboBox::Policy arg0 = TTQComboBox::AtBottom; // TODO (hack for combo box)
+ TQComboBox::Policy arg0 = TQComboBox::AtBottom; // TODO (hack for combo box)
instance->setInsertionPolicy(
arg0 );
@@ -794,10 +794,10 @@ KJS::Value TQComboBoxImp::insertionPolicy_33( KJS::ExecState *exec, KJS::Object
KJS::Value TQComboBoxImp::setValidator_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TTQValidator *
return KJS::Value();
- const TTQValidator * arg0; // Dummy
+ const TQValidator * arg0; // Dummy
instance->setValidator(
arg0 );
@@ -809,17 +809,17 @@ KJS::Value TQComboBoxImp::validator_35( KJS::ExecState *exec, KJS::Object &obj,
{
instance->validator( );
- return KJS::Value(); // Returns 'const TTQValidator *'
+ return KJS::Value(); // Returns 'const TQValidator *'
}
KJS::Value TQComboBoxImp::setListBox_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQListBox *
return KJS::Value();
- TTQListBox * arg0; // Dummy
+ TQListBox * arg0; // Dummy
instance->setListBox(
arg0 );
@@ -831,17 +831,17 @@ KJS::Value TQComboBoxImp::listBox_37( KJS::ExecState *exec, KJS::Object &obj, co
{
instance->listBox( );
- return KJS::Value(); // Returns 'TTQListBox *'
+ return KJS::Value(); // Returns 'TQListBox *'
}
KJS::Value TQComboBoxImp::setLineEdit_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQLineEdit *
return KJS::Value();
- TTQLineEdit * arg0; // Dummy
+ TQLineEdit * arg0; // Dummy
instance->setLineEdit(
arg0 );
@@ -853,7 +853,7 @@ KJS::Value TQComboBoxImp::lineEdit_39( KJS::ExecState *exec, KJS::Object &obj, c
{
instance->lineEdit( );
- return KJS::Value(); // Returns 'TTQLineEdit *'
+ return KJS::Value(); // Returns 'TQLineEdit *'
}
@@ -880,15 +880,15 @@ KJS::Value TQComboBoxImp::autoCompletion_41( KJS::ExecState *exec, KJS::Object &
KJS::Value TQComboBoxImp::eventFilter_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQObject *
return KJS::Value();
- TTQObject * arg0; // Dummy
+ TQObject * arg0; // Dummy
- // Unsupported parameter TTQEvent *
+ // Unsupported parameter TQEvent *
return KJS::Value();
- TTQEvent * arg1; // Dummy
+ TQEvent * arg1; // Dummy
bool ret;
ret = instance->eventFilter(
@@ -150,25 +150,25 @@ void TQComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQComboBox pointer from an Object.
+ * Extract a TQComboBox pointer from an Object.
*/
@@ -198,15 +198,15 @@ KJS::Object TQComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &arg
{
#if 0
- // Unsupported parameter TTQWidget *
+ // Unsupported parameter TQWidget *
return KJS::Value();
@@ -198,15 +198,15 @@ KJS::Object TQComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &arg
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
- // We should now create an object of type TQComboBoxTQComboBox *ret = new TTQComboBox(
+ // We should now create an object of type TQComboBoxTQComboBox *ret = new TQComboBox(
arg0,
arg1 );
@@ -219,15 +219,15 @@ KJS::Object TQComboBoxImp::TQComboBox_2( KJS::ExecState *exec, const KJS::List &
#if 0
bool arg0 = extractBool(exec, args, 0);
- // Unsupported parameter TTQWidget *
+ // Unsupported parameter TQWidget *
return KJS::Value();
@@ -219,15 +219,15 @@ KJS::Object TQComboBoxImp::TQComboBox_2( KJS::ExecState *exec, const KJS::List &
const char *arg2 = (args.size() >= 3) ? args[2].toString(exec).ascii() : 0;
- // We should now create an object of type TQComboBoxTQComboBox *ret = new TTQComboBox(
+ // We should now create an object of type TQComboBoxTQComboBox *ret = new TQComboBox(
arg0,
arg1,
@@ -472,10 +472,10 @@ KJS::Value TQComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQComboBoxImp::insertStrList_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const TTQStrList *
+ // Unsupported parameter const TQStrList *
return KJS::Value();
@@ -794,10 +794,10 @@ KJS::Value TQComboBoxImp::insertionPolicy_33( KJS::ExecState *exec, KJS::Object
KJS::Value TQComboBoxImp::setValidator_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const TTQValidator *
+ // Unsupported parameter const TQValidator *
return KJS::Value();
@@ -809,17 +809,17 @@ KJS::Value TQComboBoxImp::validator_35( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQComboBoxImp::setListBox_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQListBox *
+ // Unsupported parameter TQListBox *
return KJS::Value();
@@ -831,17 +831,17 @@ KJS::Value TQComboBoxImp::listBox_37( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value TQComboBoxImp::setLineEdit_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQLineEdit *
+ // Unsupported parameter TQLineEdit *
return KJS::Value();
@@ -880,15 +880,15 @@ KJS::Value TQComboBoxImp::autoCompletion_41( KJS::ExecState *exec, KJS::Object &
KJS::Value TQComboBoxImp::eventFilter_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQObject *
+ // Unsupported parameter TQObject *
return KJS::Value();